#define DEBUG 1
#define OSSOLOG_SYSLOG 1
#include <osso-log.h>

#include <QApplication>
#include <qmaemo5homescreenadaptor.h>
#include "profilechangerwidget.h"

int main(int argc, char *argv[])
{
    QApplication::setOrganizationName("hschmitt");
    QApplication::setApplicationName("profile-changer-widget");
    QApplication::setApplicationVersion("0.4-5");
    ULOG_INFO_L("Starting profile-changer-widget");
    ULOG_WARN_L("Starting profile-changer-widget");
    // enforce native graphics system for now due to a bug in transparency handling
    // you can remove this line if you only target PR 1.2
    if (qstrcmp(qVersion(), "4.7.2") == 0) {
        QApplication::setGraphicsSystem("native");
        qWarning("profile-changer-widget Using native graphicssystem");
    }

    QApplication app(argc, argv);
    qWarning("profile-changer-widget adaptor");
    ProfileChangerWidget w;

    QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&w);
    qWarning("profile-changer-widget settings");
    adaptor->setSettingsAvailable(false);
    qWarning("profile-changer-widget settings connect");
//    QObject::connect(adaptor, SIGNAL(settingsRequested()), &w, SLOT(onShowSettingsDialog()));

 //   const QStringList args = QApplication::arguments();

    // parse the command line arguments.
//    int idx;
//    if ((idx = args.indexOf(QLatin1String("-plugin-id"))) != -1)
//    {
//        w.setAppletId(args.value(idx + 1));
//    }


    qWarning("profile-changer-widget show");
    w.show();
    ULOG_INFO_L("profile-changer-widget app.exec");
    app.exec();
}

